aboutsummaryrefslogtreecommitdiffstats
path: root/shell/e-storage-set-view.c
diff options
context:
space:
mode:
Diffstat (limited to 'shell/e-storage-set-view.c')
-rw-r--r--shell/e-storage-set-view.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/shell/e-storage-set-view.c b/shell/e-storage-set-view.c
index 461b05411d..370e11c104 100644
--- a/shell/e-storage-set-view.c
+++ b/shell/e-storage-set-view.c
@@ -1363,13 +1363,14 @@ etree_icon_at (ETreeModel *etree,
path = (char*)e_tree_memory_node_get_data (E_TREE_MEMORY(etree), tree_path);
- /* Storages, My Evolution is the only special case for now */
+ /* Storages, Summary (nee My Evolution) is the only special case for now */
+ g_print ("path: %s\n", path);
if (depth == 1 && !strcmp (path, "/summary")) { /* Storages */
folder_type_registry = e_storage_set_get_folder_type_registry (storage_set);
icon_pixbuf = e_folder_type_registry_get_icon_for_type (folder_type_registry,
- "My Evolution", TRUE);
+ "Summary", TRUE);
return icon_pixbuf;
}
/* Folders */
@@ -1461,7 +1462,7 @@ etree_value_at (ETreeModel *etree, ETreePath tree_path, int col, void *model_dat
}
if (col == 0)
- return _("My Evolution");
+ return _("Summary");
else
return (void *) TRUE;
}